@@ -70,6 +70,21 @@ class Client:
             res.append(data)
         return res
 
+    def sub(self, symbols: list, data_type: bytes, sub_handler):
+        for symbol in symbols:
+            msub = message.Sub(symbol, data_type)
+            self.send(msub)
+            
+        while True:
+            msubr = message.SubR()
+            self.recv(msubr)
+
+            data = {}
+            error_code = msubr.get_field('error_code')
+            if error_code == 0:
+                data = yaml.load(msubr.get_field('data').decode("utf-8"))
+            sub_handler(data, error_code)
+
 if __name__ == '__main__':
     client = Client('127.0.0.1', 23456)
     client.connect()
